@@ -85,12 +85,26 @@ Amatrix <- function(data = NULL,
   cat("Organizing data... \n")
   orig.order <- as.character(data[,1])
   data.after.treat <- try(datatreat(data=data,unk=unk,...),silent=TRUE)
-  if(inherits(data.after.treat,"try-error") | (length(unique(data.after.treat$ind.data))!=nrow(data))){
+  
+  # checking if order was fixed
+  flag = FALSE
+  flag = inherits(data.after.treat,"try-error")
+  if(!flag)
+    flag = (length(unique(data.after.treat$ind.data))!=nrow(data))
+
+if(flag){
       cat("To organize the data in a fast way wasn't possible... \n")
       cat("Trying to organize in a slow (naive) way... \n")
       data.sorted <- sortped(data)
       data.after.treat <- try(datatreat(data=data.sorted,unk=unk,...))
-      if(inherits(data.after.treat,"try-error") | (length(unique(data.after.treat$ind.data))!=nrow(data))){
+
+      # checking if order was fixed
+      flag = FALSE
+      flag = inherits(data.after.treat,"try-error")
+      if(!flag)
+        flag = (length(unique(data.after.treat$ind.data))!=nrow(data))
+  
+      if(flag){
           cat("It wasn't possible to organize your data chronologically. We recommend you to do it by hand or use the flag 'naive_sort=TRUE'. If the problem persists, please contact this package mainteiner \n")
           return()
       }
